@@ -17,11 +17,7 @@
  * 
  */
 
-#if !defined (__FreeBSD__)
-#define _XOPEN_SOURCE 600
-#else
-#define _XOPEN_SOURCE
-#endif
+#include "config.h"
 
 #include <sys/types.h>
 #include <stdio.h>
