@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2015 the Claws Mail Team
+ * Copyright (C) 2002-2022 the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@
 #include "prefs.h"
 #include "claws.h"
 #include "timing.h"
+#include "file-utils.h"
 
 #ifdef G_OS_WIN32
 #define PLUGINS_BLOCK_PREFIX "PluginsWin32_"
@@ -73,7 +74,7 @@ const gchar *plugin_feature_names[] =
 	  N_("filtering"),
 	  N_("a privacy interface"),
 	  N_("a notifier"),
-	  N_("an utility"),
+	  N_("a utility"),
 	  N_("things"),
 	  NULL };
 
@@ -153,6 +154,7 @@ void plugin_save_list(void)
 		    (prefs_set_block_label(pfile, block) < 0)) {
 			g_warning("failed to write plugin list");
 			g_free(rcpath);
+			g_free(block);
 			return;
 		}
 		g_free(block);
@@ -245,13 +247,13 @@ static gint plugin_load_deps(const gchar *filename, gchar **error)
 	deps_file = g_strconcat(tmp, ".deps", NULL);
 	g_free(tmp);
 	
-	fp = g_fopen(deps_file, "rb");
+	fp = claws_fopen(deps_file, "rb");
 	g_free(deps_file);
 	
 	if (!fp)
 		return 0;
 	
-	while (fgets(buf, sizeof(buf), fp) != NULL) {
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
 		Plugin *dep_plugin = NULL;
 		gchar *path = NULL;
 		buf[strlen(buf)-1]='\0'; /* chop off \n */
@@ -262,7 +264,7 @@ static gint plugin_load_deps(const gchar *filename, gchar **error)
 			dep_plugin = plugin_load(path, error);
 			if (dep_plugin == NULL) {
 				g_free(path);
-				fclose(fp);
+				claws_fclose(fp);
 				return -1;
 			}
 			dep_plugin->in_prefix_dir = TRUE;
@@ -278,7 +280,7 @@ static gint plugin_load_deps(const gchar *filename, gchar **error)
 					g_strdup(filename));
 		}
 	}
-	fclose(fp);
+	claws_fclose(fp);
 	return 0;
 }
 
@@ -582,7 +584,9 @@ static void replace_old_plugin_name(gchar *plugin_name)
 		
 		strncpy(plugin_name + offset, new_name_end, strlen(old_name_end) - 1);
 		debug_print(" to %s\n", plugin_name);
+		g_free(new_name_end);
 	}
+	g_free(old_name_end);
 }
 
 void plugin_load_all(const gchar *type)
@@ -599,13 +603,14 @@ void plugin_load_all(const gchar *type)
 	if ((pfile = prefs_read_open(rcpath)) == NULL ||
 	    (prefs_set_block_label(pfile, block) < 0)) {
 		g_free(rcpath);
+		g_free(block);
 		if (pfile)
 			prefs_file_close(pfile);
 		return;
 	}
 	g_free(block);
 
-	while (fgets(buf, sizeof(buf), pfile->fp) != NULL) {
+	while (claws_fgets(buf, sizeof(buf), pfile->fp) != NULL) {
 		if (buf[0] == '[')
 			break;
 
