@@ -201,12 +201,12 @@ static void export_ok_cb(GtkWidget *widget, gpointer data)
 	srcdir = gtk_entry_get_text(GTK_ENTRY(src_entry));
 	utf8mbox = gtk_entry_get_text(GTK_ENTRY(file_entry));
 
-	if (utf8mbox && !*utf8mbox) {
+	if (!utf8mbox || !*utf8mbox) {
 		alertpanel_error(_("Target mbox filename can't be left empty."));
 		gtk_widget_grab_focus(file_entry);
 		return;
 	}
-	if (srcdir && !*srcdir) {
+	if (!srcdir || !*srcdir) {
 		alertpanel_error(_("Source folder can't be left empty."));
 		gtk_widget_grab_focus(src_entry);
 		return;
@@ -214,7 +214,7 @@ static void export_ok_cb(GtkWidget *widget, gpointer data)
 
 	mbox = g_filename_from_utf8(utf8mbox, -1, NULL, NULL, NULL);
 	if (!mbox) {
-		g_warning("export_ok_cb(): failed to convert character set.");
+		g_warning("export_ok_cb(): failed to convert character set");
 		mbox = g_strdup(utf8mbox);
 	}
 
@@ -253,7 +253,7 @@ static void export_filesel_cb(GtkWidget *widget, gpointer data)
 						conv_get_locale_charset_str(),
 						CS_UTF_8);
 		if (!filename) {
-			g_warning("export_filesel_cb(): failed to convert character set.");
+			g_warning("export_filesel_cb(): failed to convert character set");
 			filename = g_strdup(oldstr);
 		}
 		gtk_entry_set_text(GTK_ENTRY(file_entry), filename);
