@@ -345,7 +345,7 @@ static GtkCMCTreeNode *grouplist_create_branch(NewsGroupInfo *ginfo,
 	else if (ginfo->type == 'm')
 		cols[2] = _("moderated");
 	else if (ginfo->type == 'n')
-		cols[2] = _("readonly");
+		cols[2] = _("read-only");
 	else
 		cols[2] = _("unknown");
 
@@ -378,7 +378,7 @@ static GtkCMCTreeNode *grouplist_create_branch(NewsGroupInfo *ginfo,
 
 static void grouplist_expand_upwards(GtkCMCTree *ctree, const gchar *name) {
 	const gchar *ptr;
-	gchar *newname=g_malloc0(strlen(name));
+	gchar *newname=g_malloc0(strlen(name) + 1);
 	GtkCMCTreeNode *node;
 
 	for (ptr=name; *ptr; ptr++) {
