@@ -1410,7 +1410,8 @@ static gboolean replace_key_pressed(GtkWidget *widget,
 	if (event && event->keyval == GDK_KEY_Escape) {
 		gtk_widget_destroy(widget);
 		return TRUE;
-	} else if (event && event->keyval == GDK_KEY_Return) {
+	} else if (event && (event->keyval == GDK_KEY_KP_Enter ||
+		   event->keyval == GDK_KEY_Return)) {
 		replace_with_supplied_word_cb(widget, gtkaspell);
 		return TRUE;
 	}
@@ -1432,7 +1433,7 @@ static void replace_with_create_dialog_cb(GtkWidget *w, gpointer data)
 	GtkWidget *parent_window;
 	GtkWidget *content_area;
 	GtkWidget *action_area;
-	gchar *utf8buf, *thelabel;
+	gchar *utf8buf, *thelabel, *format;
 	gint xx, yy;
 	GtkAspell *gtkaspell = (GtkAspell *) data;
 
@@ -1463,9 +1464,10 @@ static void replace_with_create_dialog_cb(GtkWidget *w, gpointer data)
 
 	utf8buf  = g_strdup(gtkaspell->theword);
 
-	thelabel = g_strdup_printf(g_strconcat("<span weight=\"bold\" size=\"larger\">",
-					_("Replace \"%s\" with: "), "</span>", NULL),
-				   utf8buf);
+	format = g_strconcat("<span weight=\"bold\" size=\"larger\">",
+					_("Replace \"%s\" with: "), "</span>", NULL);
+	thelabel = g_strdup_printf(format, utf8buf);
+	g_free(format);
 	
 	icon = gtk_image_new_from_stock(GTK_STOCK_DIALOG_QUESTION,
         				GTK_ICON_SIZE_DIALOG); 
