@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
+ * Copyright (C) 1999-2023 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -102,7 +102,8 @@ static gboolean mimeview_scrolled	(GtkWidget	*widget,
 					 GdkEventScroll	*event,
 					 MimeView	*mimeview);
 
-static void mimeview_save_all		(MimeView	*mimeview);
+static void mimeview_save_all		(MimeView	*mimeview,
+					 gboolean	 attachments_only);
 #ifndef G_OS_WIN32
 static void mimeview_open_part_with	(MimeView	*mimeview,
 					 MimeInfo	*partinfo,
@@ -203,7 +204,12 @@ static void mimeview_save_as_cb(GtkAction *action, gpointer data)
 
 static void mimeview_save_all_cb(GtkAction *action, gpointer data)
 {
-	mimeview_save_all((MimeView *)data);
+	mimeview_save_all((MimeView *)data, FALSE);
+}
+
+static void mimeview_save_all_attachments_cb(GtkAction *action, gpointer data)
+{
+	mimeview_save_all((MimeView *)data, TRUE);
 }
 
 static void mimeview_select_next_part_cb(GtkAction *action, gpointer data)
@@ -227,6 +233,7 @@ static GtkActionEntry mimeview_menu_actions[] = {
 	{ "MimeView/DisplayAsText", NULL, N_("_Display as text"), NULL, "Display as text", G_CALLBACK(mimeview_display_as_text_cb) },
 	{ "MimeView/SaveAs", NULL, N_("_Save as..."), NULL, "Save as", G_CALLBACK(mimeview_save_as_cb) },
 	{ "MimeView/SaveAll", NULL, N_("Save _all..."), NULL, "Save all parts", G_CALLBACK(mimeview_save_all_cb) },
+	{ "MimeView/SaveAllAttachments", NULL, N_("Save all attachments..."), NULL, "Save all attachments", G_CALLBACK(mimeview_save_all_attachments_cb) },
 	{ "MimeView/NextPart", NULL, N_("Next part"), NULL, "Next part", G_CALLBACK(mimeview_select_next_part_cb) },
 	{ "MimeView/PrevPart", NULL, N_("Previous part"), NULL, "Previous part", G_CALLBACK(mimeview_select_prev_part_cb) }
 };
@@ -443,6 +450,9 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
 			"/Menus/MimeView/", "SaveAll", "MimeView/SaveAll",
 			GTK_UI_MANAGER_MENUITEM);
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "SaveAllAttachments", "MimeView/SaveAllAttachments",
+			GTK_UI_MANAGER_MENUITEM);
 	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
 			"/Menus/MimeView/", "NextPart", "MimeView/NextPart",
 			GTK_UI_MANAGER_MENUITEM);
@@ -1645,7 +1655,7 @@ static void mimeview_drag_data_get(GtkWidget	    *widget,
 
 		fp = claws_fopen(partinfo->data.filename, "rb");
 		if (fp != NULL && fseek(fp, partinfo->offset, SEEK_SET) == 0) {
-			headers = procheader_get_header_array_asis(fp);
+			headers = procheader_get_header_array(fp);
 			if (headers) {
 				gint i;
 				for (i = 0; i < headers->len; i++) {
@@ -1864,7 +1874,7 @@ static void mimeview_save_all_info(gint errors, gint total)
  * Menu callback: Save all attached files
  * \param mimeview Current display
  */
-static void mimeview_save_all(MimeView *mimeview)
+static void mimeview_save_all(MimeView *mimeview, gboolean attachments_only)
 {
 	MimeInfo *partinfo;
 	gchar *dirname;
@@ -1909,10 +1919,14 @@ static void mimeview_save_all(MimeView *mimeview)
 	}
 
 	while (partinfo != NULL) {
-		if (partinfo->type != MIMETYPE_MESSAGE &&
-		    partinfo->type != MIMETYPE_MULTIPART &&
-		    (partinfo->disposition != DISPOSITIONTYPE_INLINE
-		     || get_real_part_name(partinfo) != NULL)) {
+		if ((!attachments_only &&
+		    (partinfo->type != MIMETYPE_MESSAGE &&
+		     partinfo->type != MIMETYPE_MULTIPART &&
+		     (partinfo->disposition != DISPOSITIONTYPE_INLINE ||
+		      get_real_part_name(partinfo) != NULL))) ||
+		    (attachments_only &&
+		     (partinfo->disposition == DISPOSITIONTYPE_ATTACHMENT &&
+		      get_real_part_name(partinfo) != NULL))) {
 			gchar *filename = mimeview_get_filename_for_part(
 				partinfo, dirname, number++);
 
