@@ -64,7 +64,10 @@ static int permissions = 0;
 
 static void free_msg_trash(MsgTrash* trash) {
     if (trash) {
-        debug_print("Freeing files in %s\n", folder_item_get_name(trash->item));
+        gchar *name = folder_item_get_name(trash->item);
+
+        debug_print("Freeing files in %s\n", name);
+        g_free(name);
         if (trash->msgs) {
             g_slist_free(trash->msgs);
         }
@@ -97,9 +100,13 @@ void archive_free_archived_files() {
     GSList* l = NULL;
    
     for (l = msg_trash_list; l; l = g_slist_next(l)) {
+        gchar *name;
+
         mt = (MsgTrash *) l->data;
+        name = folder_item_get_name(mt->item);
         debug_print("Trashing messages in folder: %s\n", 
-                folder_item_get_name(mt->item));
+                name);
+        g_free(name);
         res = folder_item_remove_msgs(mt->item, mt->msgs);
         debug_print("Result was %d\n", res);
         free_msg_trash(mt);
@@ -149,7 +156,7 @@ static gboolean is_iso_string(gchar** items) {
 
 static GDate* iso2GDate(const gchar* date) {
     GDate*  gdate;
-    gchar** parts = NULL;
+    gchar** parts;
     int     i;
 
     g_return_val_if_fail(date != NULL, NULL);
@@ -158,8 +165,10 @@ static GDate* iso2GDate(const gchar* date) {
     parts = g_strsplit(date, "-", 3);
     if (!parts)
         return NULL;
-    if (! is_iso_string(parts))
+    if (! is_iso_string(parts)) {
+        free_all(gdate, parts);
         return NULL;
+    }
     for (i = 0; i < 3; i++) {
         int t = atoi(parts[i]);
         switch (i) {
@@ -198,7 +207,7 @@ gboolean before_date(time_t msg_mtime, const gchar* before) {
 
     debug_print("Cut-off date: %s\n", before);
     if ((date = iso2GDate(before)) == NULL) {
-        g_warning("Bad date format: %s", before);
+        g_warning("bad date format: %s", before);
         return FALSE;
     }
 
@@ -213,7 +222,7 @@ gboolean before_date(time_t msg_mtime, const gchar* before) {
     }
 
     if (! g_date_valid(file_t)) {
-        g_warning("Invalid msg date");
+        g_warning("invalid msg date");
         return FALSE;
     }
 
@@ -250,14 +259,16 @@ void archive_free_file_list(gboolean md5, gboolean rename) {
 		if (!rename && md5 && g_str_has_suffix(file->name, ".md5")) {
 			path = g_strdup_printf("%s/%s", file->path, file->name);
 			debug_print("unlinking %s\n", path);
-			g_unlink(path);
+			if (g_unlink(path) < 0)
+                                FILE_OP_ERROR(path, "g_unlink");
 			g_free(path);
 		}
 		if (rename) {
 			path = g_strdup_printf("%s/%s", file->path, file->name);
 			debug_print("unlinking %s\n", path);
-			g_unlink(path);
-			g_free(path);
+			if (g_unlink(path) < 0)
+                                FILE_OP_ERROR(path, "g_unlink");
+                        g_free(path);
 		}
 		archive_free_file_info(file);
 		file_list->data = NULL;
@@ -604,6 +615,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 						buf = g_file_read_link(filename, &err);
 						if (err) {
 							FILE_OP_ERROR(filename, "g_file_read_link");
+							g_clear_error(&err);
 						} else {
 							archive_entry_set_symlink(entry, buf);
 							g_free(buf);
@@ -627,8 +639,11 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 					}
 					archive_entry_free(entry);
 				}
-				if (!g_close(fd, &err) || err)
+				if (!g_close(fd, &err) || err) {
 					FILE_OP_ERROR(filename, "g_close");
+					if (err)
+						g_clear_error(&err);
+                }
 			}
 		}
 		g_free(filename);
