@@ -38,7 +38,6 @@
 #include "summaryview.h"
 #include "folder.h"
 #include "version.h"
-#include "summaryview.h"
 #include "procmime.h"
 #include "alertpanel.h"
 #include "inc.h"
@@ -285,25 +284,25 @@ static void fill_attachment_store(GtkTreeView *list_view, MimeInfo *partinfo)
 	partinfo = procmime_mimeinfo_next(partinfo);
 	if (!partinfo)
 		return;
-		
+
 	while (partinfo) {
 		if (MIMEINFO_NOT_ATTACHMENT(partinfo)) {
     			partinfo = procmime_mimeinfo_next(partinfo);
 			continue;
 		}
-			
+
 		content_type = procmime_get_content_type_str(
 					partinfo->type, partinfo->subtype);
-		
-		name = procmime_mimeinfo_get_parameter(partinfo, "filename");
+
+		name = g_markup_escape_text(procmime_mimeinfo_get_parameter(partinfo, "filename"), -1);
 		if (!name)
-			name = procmime_mimeinfo_get_parameter(partinfo, "name");
+			name = g_markup_escape_text(procmime_mimeinfo_get_parameter(partinfo, "name"), -1);
 		if (!name)
 			name = _("unknown");
-		
-		label = g_strconcat("<b>",_("Type:"), "</b> ", content_type, "   <b>",
-			 _("Size:"), "</b> ", to_human_readable((goffset)partinfo->length),
-			"\n", "<b>", _("Filename:"), "</b> ", name, NULL);
+
+		label = g_strconcat("<b>", _("Type"), ":</b> ", content_type, "   <b>",
+			 _("Size"), ":</b> ", to_human_readable((goffset)partinfo->length),
+			"\n", "<b>", _("Filename"), ":</b> ", name, NULL);
 
 		gtk_list_store_append(list_store, &iter);
 		gtk_list_store_set(list_store, &iter,
@@ -561,7 +560,7 @@ gboolean plugin_done(void)
         	return TRUE;
         
 	if (prefs_write_param(prefs, pref_file->fp) < 0) {
-		g_warning("failed to write AttRemover Plugin configuration");
+		g_warning("failed to write AttRemover plugin configuration");
 		prefs_file_close_revert(pref_file);
 		return TRUE;
         }
