@@ -16,6 +16,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <errno.h>
 
 #include <glib.h>
@@ -30,12 +32,10 @@
 
 #include <inttypes.h>
 
-#include "plugin.h"
 #include "file-utils.h"
 
 #define LOG_NAME	"NewLog"
 #define DEFAULT_DIR	"Mail"
-#define BUFSIZE		2048
 
 static gulong hook_id = HOOK_NONE;
 
