@@ -62,17 +62,15 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 
 	debug_print("RSSyl: parsing '%s'\n", path);
 
-	g_file_get_contents(path, &contents, NULL, &error);
-
-	if( error ) {
-		g_warning("GError: '%s'", error->message);
+	if( !g_file_get_contents(path, &contents, NULL, &error) ) {
+		g_warning("error: '%s'", error->message);
 		g_error_free(error);
 	}
 
 	if( contents != NULL ) {
 		lines = strsplit_no_copy(contents, '\n');
 	} else {
-		g_warning("Badly formatted file found, ignoring: '%s'", path);
+		g_warning("badly formatted file found, ignoring: '%s'", path);
 		return NULL;
 	}
 
@@ -138,7 +136,7 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 				/* Last-Seen timestamp */
 				if( !strcmp(line[0], "X-RSSyl-Last-Seen") ) {
 					ctx->last_seen = atol(line[1]);
-					debug_print("RSSyl: got last_seen timestamp %"G_GSIZE_FORMAT"\n", ctx->last_seen);
+					debug_print("RSSyl: got last_seen timestamp %"CM_TIME_FORMAT"\n", ctx->last_seen);
 				}
 
 				/* ID */
@@ -198,6 +196,11 @@ FeedItem *rssyl_parse_folder_item_file(gchar *path)
 			if( !strcmp(lines[i], RSSYL_TEXT_START) ) {
 				debug_print("RSSyl: Leading html tag found at line %d\n", i);
 				past_html_tag = TRUE;
+				if (body)
+				{
+					g_warning("unexpected leading html tag found at line %d", i);
+				    g_string_free(body, TRUE);
+				}
 				body = g_string_new("");
 				i++;
 				continue;
