@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Colin Leroy and the Claws Mail team
+ * Copyright (C) 1999-2021 the Claws Mail team and Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -147,10 +147,10 @@ static GtkWidget *ssl_manager_list_view_create	(void)
 
 	model = GTK_TREE_MODEL(ssl_manager_create_data_store());
 	list_view = GTK_TREE_VIEW(gtk_tree_view_new_with_model(model));
-	g_object_unref(model);	
 	
  	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model),
                                              0, GTK_SORT_ASCENDING);
+	g_object_unref(model);	
 	gtk_tree_view_set_rules_hint(list_view, prefs_common.use_stripes_everywhere);
 	
 	selector = gtk_tree_view_get_selection(list_view);
@@ -192,7 +192,7 @@ void ssl_manager_create(void)
 
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "ssl_manager");
 	gtk_window_set_title (GTK_WINDOW(window),
-			      _("Saved SSL/TLS certificates"));
+			      _("Saved TLS certificates"));
 
 	gtk_container_set_border_width (GTK_CONTAINER (window), 8);
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
@@ -346,6 +346,7 @@ static void ssl_manager_load_certs (void)
 		debug_print("couldn't open dir '%s': %s (%d)\n", path,
 				error->message, error->code);
 		g_error_free(error);
+        g_free(path);
 		return;
 	}
 	
@@ -366,11 +367,13 @@ static void ssl_manager_load_certs (void)
 							server, port, cert);
 				}
 			}
-		
-			g_free(server);
-			g_free(port);
-			g_free(fp);
 		}
+		if (server)
+			g_free(server);
+		if (port)
+			g_free(port);
+		if (fp)
+			g_free(fp);
 		row++;
 	}
 	g_dir_close(dir);
